Release history and notes
=========================

`Sequence based identifiers
<http://en.wikipedia.org/wiki/Software_versioning#Sequence-based_identifiers>`_
are used for versioning (schema follows below):

.. code-block:: text

    major.minor[.revision]

- It's always safe to upgrade within the same minor version (for example, from
  0.3 to 0.3.4).
- Minor and major version changes might be backwards incompatible. Read the
  release notes carefully before upgrading (for example, when upgrading from
  0.3.4 to 0.4).
- All backwards incompatible changes are mentioned in this document.

0.1.2
-----
2025-03-16

- Test against Python 3.12 and 3.13.
- Test against all supported versions of Django (4.2, 5.0 and 5.1).

0.1.1
-----
2024-09-11

- Minor optimisations.

0.1
-----
2024-08-14

- Initial beta release.
